self.machine.hardware_platforms['{name}']
{module_underline}

.. autoclass:: {full_path_to_class}
   :members:
   :show-inheritance:

   .. rubric:: Accessing the {name} platform via code

   Hardware platforms are stored in the ``self.machine.hardware_platforms`` dictionary, so the {name} platform
   is available via ``self.machine.hardware_platforms['{name}']``.

   .. rubric:: Methods & Attributes

   The {name} platform has the following methods & attributes available. Note that methods & attributes inherited from
   base classes are not included here.